@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -104,7 +104,7 @@ BOOST_FIXTURE_TEST_CASE(test_simple_dataset,  HDF5CoreFileFixture)
 		auto space = H5Space::create(2, dims); 
 		auto dataset = H5Dataset::create(get_file(), "/testset", file_type, space);
 		
-		dataset.write(data.begin(), data.end());
+		dataset.write_data(data, int());
 	}
 	// close data set automatically, and now reopen it 
 	{
@@ -121,7 +121,7 @@ BOOST_FIXTURE_TEST_CASE(test_simple_dataset,  HDF5CoreFileFixture)
 
 		vector<int> read_data(6);
 		
-		dataset.read(read_data.begin(), read_data.end()); 
+		dataset.read_data(read_data, int()); 
 
 		for (int i = 0; i < 6; ++i)
 			BOOST_CHECK_EQUAL(read_data[i], data[i]); 
@@ -145,7 +145,7 @@ BOOST_FIXTURE_TEST_CASE(test_bool_dataset,  HDF5CoreFileFixture)
 		auto space = H5Space::create(2, dims); 
 		auto dataset = H5Dataset::create(get_file(), "/testset", file_type, space);
 		
-		dataset.write(data.begin(), data.end());
+		dataset.write_data(data, true);
 	}
 	// close data set automatically, and now reopen it 
 	{
@@ -162,7 +162,7 @@ BOOST_FIXTURE_TEST_CASE(test_bool_dataset,  HDF5CoreFileFixture)
 
 		vector<bool> read_data(6); 
 		
-		dataset.read(read_data.begin(), read_data.end()); 
+		dataset.read_data(read_data, false); 
 
 		for (int i = 0; i < 6; ++i)
 			BOOST_CHECK_EQUAL(read_data[i], data[i]); 
@@ -197,7 +197,7 @@ void TestDatasetFixture<T>::save(const string& path, const std::vector<hsize_t>&
 	
 	auto space = H5Space::create(size); 
 	auto dataset = H5Dataset::create(get_file(), path.c_str(), file_type, space);
-	dataset.write(data.begin(), data.end());
+	dataset.write_data(data, T());
 }
 
 template <typename T> 
@@ -222,7 +222,7 @@ void TestDatasetFixture<T>::read_and_test(const string& path, const std::vector<
 	
 	std::vector<T> read_data(length); 
 	
-	dataset.read(read_data.begin(), read_data.end()); 
+	dataset.read_data(read_data, T()); 
 		
 	for (size_t i = 0; i < length; ++i)
 		BOOST_CHECK_EQUAL(read_data[i], test_data[i]); 
@@ -266,11 +266,19 @@ void TestAttrfixture<T>::run()
 
 	auto pattr = H5AttributeTranslatorMap::instance().translate("attr", h5attr); 
 	int test_type = attribute_type<T>::value; 
-	BOOST_CHECK_EQUAL(pattr->type_id(), test_type); 
-
-	auto& rattr = dynamic_cast<const TAttribute<T>&>(*pattr); 
+	BOOST_CHECK_EQUAL(pattr->type_id(), test_type);
 	
-	BOOST_CHECK_EQUAL(rattr, value); 
+
+	
+
+	auto rattr = dynamic_cast<const TAttribute<T>*>(pattr.get());
+	if (!rattr)  {
+		cvdebug() << "cast from'" << typeid(attr.get()).name()
+			  <<"' to '" << typeid(TAttribute<T> *).name() << "' failed\n";		
+	}
+	BOOST_REQUIRE(rattr); 
+	
+	BOOST_CHECK_EQUAL(*rattr, value); 
 }
 
 BOOST_AUTO_TEST_CASE_TEMPLATE( test_attributes , T , test_pixel_types )
@@ -297,9 +305,15 @@ void TestVectorAttrfixture<T>::run()
 	int test_type = attribute_type<vector<T>>::value; 
 	BOOST_CHECK_EQUAL(pattr->type_id(), test_type); 
 
-	auto& rattr = dynamic_cast<const TAttribute<vector<T>>&>(*pattr); 
-	const vector<T> rvalue = rattr; 
-
+	auto rattr = dynamic_cast<const TAttribute<vector<T> > *>(pattr.get());
+	if (!rattr)  {
+		cvdebug() << "cast from'" << typeid(attr.get()).name()
+			  <<"' to '" << typeid(TAttribute<T> *).name() << "' failed\n";		
+	}
+	BOOST_REQUIRE(rattr); 	
+	
+	const vector<T> rvalue = *rattr; 
+	
 	BOOST_CHECK_EQUAL(rvalue.size(), value.size()); 
 	BOOST_REQUIRE(rvalue.size() == value.size()); 
 	for (auto r = rvalue.begin(), v = value.begin(); r != rvalue.end(); ++r, ++v){
