@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <addons/nifti/niftiimage.hh>
 #include <nifti1_io.h>
 
+#include <mia/core/attribute_names.hh>
 
 using namespace mia; 
 using namespace std; 
@@ -36,10 +37,38 @@ static const char *AttrID_nifti_intent_p1 = "nifti-intent_p1";
 static const char *AttrID_nifti_intent_p2 = "nifti-intent_p2"; 
 static const char *AttrID_nifti_intent_p3 = "nifti-intent_p3"; 
 
+
+
 static const char *AttrID_nifti_toffset = "nifti-toffset";       // float 
 static const char *AttrID_nifti_xyz_units = "nifti-xyz_units";   // int 
 static const char *AttrID_nifti_time_units = "nifti-time_units"; // int 
 
+/*
+  Within MIA the orientation of the images is stored like given in DICOM. 
+  To convert to a nifti-like orientation the following formula is used: 
+  
+  input: 
+     SIZE image seize in pixels 
+     SCALE pixeldim in mm 
+     ORIG_IN location of first pixel in pyhsical space 
+     R_IN    rotation orientation matrix 
+  outut: 
+     ORIG_OUT location of first pixel in pyhsical space (nifti) 
+     R_OUT    rotation orientation matrix (nifti) 
+
+                 / -1, -1,  1 \
+  R_OUT = R_IN * | -1, -1,  1 |
+                 \  1,  1, -1 /
+
+    dz = (SIZE.z - 1) * scale.z; 
+  ORIG_OUT.x = - R_IN.z.x * dz - ORIG_IN.x; 
+  ORIG_OUT.y = - R_IN.z.y * dz - ORIG_IN.y; 
+  ORIG_OUT.z =   R_IN.z.z * dz + ORIG_IN.z; 
+
+  When reading a nifti image the inverse operation is applied. 
+
+*/
+
 
 CNifti3DImageIOPlugin::CNifti3DImageIOPlugin():
 C3DImageIOPlugin("nifti")
@@ -71,6 +100,9 @@ C3DImageIOPlugin("nifti")
 	CFloatTranslator::register_for("nifti-intent_p2"); 
 	CFloatTranslator::register_for("nifti-intent_p3"); 
 
+	CFloatTranslator::register_for(IDRescaleSlope);
+	CFloatTranslator::register_for(IDRescaleIntercept); 
+	
         CFloatTranslator::register_for(AttrID_nifti_toffset); 
 	CSITranslator::register_for(AttrID_nifti_xyz_units);
 	CSITranslator::register_for(AttrID_nifti_time_units);
@@ -91,27 +123,60 @@ void copy_attributes(C3DImage& image, const nifti_image& ni)
         if (ni.qform_code == 0) { // method 1
                 image.set_orientation(ior_default);
                 image.set_voxel_size(C3DFVector(ni.dx,  ni.dy, ni.dz)); 
-        } else { // Method 2 
-                image.set_orientation(ni.qfac == 1 ? ior_xyz : ior_xyz_flipped);
-                image.set_voxel_size(C3DFVector(ni.dx,  ni.dy, ni.dz)); 
-                image.set_origin(C3DFVector(ni.qoffset_x, ni.qoffset_y, ni.qoffset_z)); 
-                double qa = sqrt(1.0 - (ni.quatern_b * ni.quatern_b + 
-                                        ni.quatern_c * ni.quatern_c + 
-                                        ni.quatern_d * ni.quatern_d)); 
-                image.set_rotation(Quaternion(qa, ni.quatern_b, ni.quatern_c, ni.quatern_d));
+        } else { // Method 2
+
+                image.set_orientation(ior_xyz);
+                image.set_voxel_size(C3DFVector(ni.dx,  ni.dy, ni.dz));
+
+		mat44 mat = nifti_quatern_to_mat44( ni.quatern_b, ni.quatern_c, ni.quatern_d,
+						    0.0f, 0.0f, 0.0f,
+						    1.0f, 1.0f, 1.0f, ni.qfac);
+
+		C3DDMatrix rot(C3DDVector(-mat.m[0][0],-mat.m[1][0], mat.m[2][0]),
+			       C3DDVector(-mat.m[0][1],-mat.m[1][1], mat.m[2][1]),
+			       C3DDVector( mat.m[0][2], mat.m[1][2],-mat.m[2][2]));
+
+		image.set_rotation(rot);
+		const float dz = (ni.nz - 1) * ni.dz; 
+
+		C3DFVector org(- rot.z.x * dz - ni.qoffset_x, 
+			       - rot.z.y * dz - ni.qoffset_y, 
+			       - rot.z.z * dz + ni.qoffset_z); 
+		
+                image.set_origin(org); 
+		
         }
         
         if (ni.sform_code > 0) { // method 3
                 vector<float> am = {ni.sto_xyz.m[0][0], ni.sto_xyz.m[0][1], ni.sto_xyz.m[0][2], ni.sto_xyz.m[0][3], 
-                                     ni.sto_xyz.m[1][0], ni.sto_xyz.m[1][1], ni.sto_xyz.m[1][2], ni.sto_xyz.m[1][3],
-                                     ni.sto_xyz.m[2][0], ni.sto_xyz.m[2][1], ni.sto_xyz.m[2][2], ni.sto_xyz.m[2][3],
-                                     ni.sto_xyz.m[3][0], ni.sto_xyz.m[3][1], ni.sto_xyz.m[3][2], ni.sto_xyz.m[3][3]}; 
+				    ni.sto_xyz.m[1][0], ni.sto_xyz.m[1][1], ni.sto_xyz.m[1][2], ni.sto_xyz.m[1][3],
+				    ni.sto_xyz.m[2][0], ni.sto_xyz.m[2][1], ni.sto_xyz.m[2][2], ni.sto_xyz.m[2][3],
+				    ni.sto_xyz.m[3][0], ni.sto_xyz.m[3][1], ni.sto_xyz.m[3][2], ni.sto_xyz.m[3][3]}; 
                 
                 image.set_attribute(AttrID_nifti_sform, am);
-                image.set_attribute(AttrID_nifti_sform_code, ni.sform_code); 
+                image.set_attribute(AttrID_nifti_sform_code, ni.sform_code);
+
+		// in this case use s-from for orientation 
+		if (ni.qform_code == 0) {
+			C3DDMatrix rot(C3DDVector(-ni.sto_xyz.m[0][0]/ni.dx,
+						  -ni.sto_xyz.m[1][0]/ni.dy,
+						   ni.sto_xyz.m[2][0]/ni.dz),
+				       C3DDVector(-ni.sto_xyz.m[0][1]/ni.dx,
+						  -ni.sto_xyz.m[1][1]/ni.dy,
+						   ni.sto_xyz.m[2][1]/ni.dz),
+				       C3DDVector( ni.sto_xyz.m[0][2]/ni.dx,
+						   ni.sto_xyz.m[1][2]/ni.dy,
+						  -ni.sto_xyz.m[2][2]/ni.dz));
+			
+			image.set_rotation(rot);
+			const float dz = (ni.nz - 1) * ni.dz; 
+			C3DFVector org(- rot.z.x * dz - ni.qoffset_x, 
+				       - rot.z.y * dz - ni.qoffset_y, 
+				       - rot.z.z * dz + ni.qoffset_z); 
+			image.set_origin(org); 
+		}
         }
         
-
 	image.set_attribute(AttrID_nifti_toffset, ni.toffset);
 	image.set_attribute(AttrID_nifti_xyz_units, ni.xyz_units);
 	image.set_attribute(AttrID_nifti_time_units, ni.time_units);
@@ -119,7 +184,9 @@ void copy_attributes(C3DImage& image, const nifti_image& ni)
 	image.set_attribute(AttrID_nifti_intent_p1, ni.intent_p1);
 	image.set_attribute(AttrID_nifti_intent_p2, ni.intent_p2);
 	image.set_attribute(AttrID_nifti_intent_p3, ni.intent_p3);
-	image.set_attribute(AttrID_nifti_intent_name, string(ni.intent_name)); 
+	image.set_attribute(AttrID_nifti_intent_name, string(ni.intent_name));
+	image.set_attribute(IDRescaleSlope, ni.scl_slope);
+	image.set_attribute(IDRescaleIntercept, ni.scl_inter); 
 }
 
 
@@ -127,8 +194,11 @@ template <typename Image>
 CNifti3DImageIOPlugin::PData read_images(const C3DBounds& size, const nifti_image& ni)
 {
         int timesteps = 1; 
-	if (ni.ndim == 4) 
-		timesteps = ni.nt; 
+	for (int extra_dims = 4; extra_dims <= ni.ndim; ++extra_dims)
+		timesteps *= ni.dim[extra_dims]; 
+
+	cvdebug() << "Loading " << timesteps << " images\n";
+
 
 	CNifti3DImageIOPlugin::PData result(new C3DImageVector); 
 	result->reserve(timesteps); 
@@ -147,33 +217,6 @@ CNifti3DImageIOPlugin::PData read_images(const C3DBounds& size, const nifti_imag
         
 }
 
-template <typename OutImage, typename InPixel> 
-CNifti3DImageIOPlugin::PData read_images(const C3DBounds& size, const nifti_image& ni)
-{
-        int timesteps = 1; 
-	if (ni.ndim == 4) 
-		timesteps = ni.nt; 
-
-	CNifti3DImageIOPlugin::PData result(new C3DImageVector); 
-	result->reserve(timesteps); 
-	
-	const InPixel *in_data = reinterpret_cast<const InPixel *>(ni.data);
-	
-	size_t stride = size.product(); 
-        
-        const double scale = ni.scl_slope; 
-        const double shift = ni.scl_inter; 
-        
-	for (int i = 0; i < timesteps; ++i, in_data += stride) {
-		auto *img = new OutImage(size); 
-                copy_attributes(*img, ni); 
-		transform(in_data, in_data + img->size(), img->begin(), 
-                          [scale, shift](InPixel x){return scale * x + shift;}); 
-		result->push_back(P3DImage(img)); 
-	}
-	return result; 
-        
-}
 
 CNifti3DImageIOPlugin::PData CNifti3DImageIOPlugin::do_load(const std::string&  filename) const
 {
@@ -196,50 +239,28 @@ CNifti3DImageIOPlugin::PData CNifti3DImageIOPlugin::do_load(const std::string&
                                                          image->intent_code, " that is not supported by MIA."); 
         }
 
-	
-
-	
-        if (image->ndim < 3 || image->ndim > 4)
+        if (image->ndim < 3 || image->ndim > 5)
 		throw create_exception<invalid_argument>("Nifti: 3D(+t) image expected but ", 
 							 image->ndim, " dimensions available in '", filename); 
         
         C3DBounds size(image->nx, image->ny, image->nz);
 
-        if (image->scl_slope != 0.0) { // data must be scaled
-                switch (image->datatype) {
-                case DT_UINT8:  return read_images<C3DFImage, unsigned char>(size, *image); 
-                case DT_INT16:  return read_images<C3DFImage, signed short>(size, *image); 
-                case DT_INT32:  return read_images<C3DDImage, signed int>(size, *image); 
-                case DT_FLOAT32:return read_images<C3DFImage, float>(size,  *image); 
-                case DT_FLOAT64:return read_images<C3DDImage, double>(size,  *image); 
-                case DT_INT8:   return read_images<C3DFImage, signed char>(size, *image); 
-                case DT_UINT16: return read_images<C3DFImage, unsigned short>(size, *image); 
-                case DT_UINT32: return read_images<C3DDImage, unsigned int>(size, *image); 
+	switch (image->datatype) {
+	case DT_UINT8:  return read_images<C3DUBImage>(size, *image); 
+	case DT_INT16:  return read_images<C3DSSImage>(size, *image); 
+	case DT_INT32:  return read_images<C3DSIImage>(size, *image); 
+	case DT_FLOAT32:return read_images<C3DFImage>(size,  *image); 
+	case DT_FLOAT64:return read_images<C3DDImage>(size,  *image); 
+	case DT_INT8:   return read_images<C3DSBImage>(size, *image); 
+	case DT_UINT16: return read_images<C3DUSImage>(size, *image); 
+	case DT_UINT32: return read_images<C3DUIImage>(size, *image); 
 #ifdef LONG_64BIT
-                case DT_INT64:  return read_images<C3DDImage, signed long>(size, *image); 
-                case DT_UINT64: return read_images<C3DDImage, unsigned short>(size, *image); 
+	case DT_INT64:  return read_images<C3DSLImage>(size, *image); 
+	case DT_UINT64: return read_images<C3DULImage>(size, *image); 
 #endif
-                default:
-                        throw create_exception<invalid_argument>("NIFTI: input format ", image->datatype, " not supported"); 
-                }
-        } else {  // the true pixel values are stored
-                switch (image->datatype) {
-                case DT_UINT8:  return read_images<C3DUBImage>(size, *image); 
-                case DT_INT16:  return read_images<C3DSSImage>(size, *image); 
-                case DT_INT32:  return read_images<C3DSIImage>(size, *image); 
-                case DT_FLOAT32:return read_images<C3DFImage>(size,  *image); 
-                case DT_FLOAT64:return read_images<C3DDImage>(size,  *image); 
-                case DT_INT8:   return read_images<C3DSBImage>(size, *image); 
-                case DT_UINT16: return read_images<C3DUSImage>(size, *image); 
-                case DT_UINT32: return read_images<C3DUIImage>(size, *image); 
-#ifdef LONG_64BIT
-                case DT_INT64:  return read_images<C3DSLImage>(size, *image); 
-                case DT_UINT64: return read_images<C3DULImage>(size, *image); 
-#endif
-                default:
-                        throw create_exception<invalid_argument>("NIFTI: input format ", image->datatype, " not supported");
-                }
-        }
+	default:
+		throw create_exception<invalid_argument>("NIFTI: input format ", image->datatype, " not supported");
+	}
 	
 }
 
@@ -283,6 +304,12 @@ public:
                         throw create_exception<invalid_argument>("NIFTI-IO: image series containing images of varying pixel types is not supported");
                 }
 
+		if (static_cast<unsigned>(m_ni.nx) != image.get_size().x ||
+		    static_cast<unsigned>(m_ni.ny) != image.get_size().y ||
+		    static_cast<unsigned>(m_ni.nz) != image.get_size().z) {
+			throw create_exception<invalid_argument>("NIFTI-IO: image series containing images of varying sizes is not supported");	
+		}
+		
                 T *out_data = reinterpret_cast<T *>(m_ni.data);
                 copy(image.begin(), image.end(), out_data + m_npixels_written);
                 m_npixels_written += image.size();
@@ -310,8 +337,9 @@ bool CNifti3DImageIOPlugin::do_save(const std::string& fname, const Data& data)
         int datatype = datatype_to_nifti(pixel_type);
         
         if (data.size() > 1) {
-                dims[0] = 4; 
-                dims[4] = data.size(); 
+		cvdebug() << "Saving " << data.size() << " images\n"; 
+                dims[0] = 5; 
+                dims[5] = data.size(); 
         }
 	
         // create the output image
@@ -336,9 +364,8 @@ bool CNifti3DImageIOPlugin::do_save(const std::string& fname, const Data& data)
 	output->dv = output->pixdim[6] = 1;
 	output->dw = output->pixdim[7] = 1;
 	
-	// we don't do scaling 
-	output->scl_slope = 0.0f;
-	output->scl_inter = 0.0f;
+	output->scl_slope = image.get_attribute_as<float>(IDRescaleSlope, 0.0f);
+	output->scl_inter = image.get_attribute_as<float>(IDRescaleIntercept, 0.0f);
 
 	// need to see whether to support this 
 	output->cal_min = 0.0f;
@@ -347,15 +374,15 @@ bool CNifti3DImageIOPlugin::do_save(const std::string& fname, const Data& data)
 	if (image.has_attribute(AttrID_nifti_qform_code)) {
 		output->qform_code = image.get_attribute_as<int>(AttrID_nifti_qform_code); 
 	} else {
-		output->qform_code = 0; // default to method 2 
+		output->qform_code = 1; // default to method 2 
 	}
 
+	auto org = image.get_origin(); 
 	// Analyze 7.5 like data 
 	if (output->qform_code == 0) {
 		// here starts the orientation insanity 
 		// todo: re-check how this qfac is actually used
 
-		auto org = image.get_origin(); 
 		output->qoffset_x = org.x; 
 		output->qoffset_y = org.y; 
 		output->qoffset_z = org.z; 
@@ -370,15 +397,31 @@ bool CNifti3DImageIOPlugin::do_save(const std::string& fname, const Data& data)
 			cvwarn() << __FUNCTION__ << "FIXME:manual set orientation detected, but ignored\n"; 
 		}
 	} else {
-		output->qfac = (image.get_orientation() == ior_xyz_flipped) ? -1 : 1; 
-		auto org = image.get_origin(); 
-		output->qoffset_x = org.x; 
-		output->qoffset_y = org.y; 
-		output->qoffset_z = org.z; 
-		auto rot = image.get_rotation().as_quaternion(); 
-		output->quatern_b = rot.x(); 
-		output->quatern_c = rot.y(); 
-		output->quatern_d = rot.z();
+		output->qform_code = NIFTI_XFORM_SCANNER_ANAT;
+
+		auto rot = image.get_rotation().as_matrix_3x3();
+
+		cvdebug() << "rot-quat= "<< image.get_rotation().as_quaternion() << "\n";
+		cvdebug() << "org= " << org << "\n";
+		cvdebug() << "rot= " << rot << "\n"; 		
+
+		const float dz = (size.z - 1) * scale.z; 
+		output->qoffset_x = - rot.z.x * dz - org.x; 
+		output->qoffset_y = - rot.z.y * dz - org.y; 
+		output->qoffset_z = rot.z.z * dz + org.z;
+
+		// this seems to be the proper transaltion 
+		output->qto_xyz = nifti_make_orthog_mat44( 
+			-rot.x.x, -rot.y.x, rot.z.x,
+			-rot.x.y, -rot.y.y, rot.z.y,
+			 rot.x.z, rot.y.z, -rot.z.z); 
+	
+		nifti_mat44_to_quatern(output->qto_xyz,
+				       &output->quatern_b, &output->quatern_c, &output->quatern_d,
+				       NULL,NULL,NULL,NULL,NULL,NULL,&output->qfac);
+
+		output->pixdim[0] = output->qfac; 
+		
 	}
 	
 	// copy s-form if available 
@@ -395,18 +438,41 @@ bool CNifti3DImageIOPlugin::do_save(const std::string& fname, const Data& data)
 		output->sto_xyz.m[1][2] = am[6]; 
 		output->sto_xyz.m[1][3] = am[7]; 
 
-		output->sto_xyz.m[1][0] = am[8]; 
-		output->sto_xyz.m[1][1] = am[9]; 
-		output->sto_xyz.m[1][2] = am[10]; 
-		output->sto_xyz.m[1][3] = am[11]; 
+		output->sto_xyz.m[2][0] = am[8]; 
+		output->sto_xyz.m[2][1] = am[9]; 
+		output->sto_xyz.m[2][2] = am[10]; 
+		output->sto_xyz.m[2][3] = am[11]; 
 
-		output->sto_xyz.m[1][0] = am[12]; 
-		output->sto_xyz.m[1][1] = am[13]; 
-		output->sto_xyz.m[1][2] = am[14]; 
-		output->sto_xyz.m[1][3] = am[15]; 
+		output->sto_xyz.m[3][0] = am[12]; 
+		output->sto_xyz.m[3][1] = am[13]; 
+		output->sto_xyz.m[3][2] = am[14]; 
+		output->sto_xyz.m[3][3] = am[15]; 
+		
+	}else{ // without a sform code leave it empty (for now)
+		output->sform_code = NIFTI_XFORM_SCANNER_ANAT;
 
-	
+		auto rot = image.get_rotation().as_matrix_3x3();
+		output->sto_xyz.m[0][0] = -rot.x.x * scale.x;
+		output->sto_xyz.m[0][1] = -rot.y.x * scale.y; 
+		output->sto_xyz.m[0][2] =  rot.z.x * scale.z; 
+		output->sto_xyz.m[0][3] = output->qoffset_x; 
+
+		output->sto_xyz.m[1][0] = -rot.x.y * scale.x; 
+		output->sto_xyz.m[1][1] = -rot.y.y * scale.y; 
+		output->sto_xyz.m[1][2] =  rot.z.y * scale.z; 
+		output->sto_xyz.m[1][3] = output->qoffset_y; 
+
+		output->sto_xyz.m[2][0] = rot.x.z * scale.y; 
+		output->sto_xyz.m[2][1] = rot.y.z * scale.y; 
+		output->sto_xyz.m[2][2] = -rot.z.z * scale.z; 
+		output->sto_xyz.m[2][3] = output->qoffset_z; 
+
+		output->sto_xyz.m[3][0] = 0; 
+		output->sto_xyz.m[3][1] = 0; 
+		output->sto_xyz.m[3][2] = 0; 
+		output->sto_xyz.m[3][3] = 1;  
 	}
+	
 	output->toffset = image.get_attribute_as<float>(AttrID_nifti_toffset, 0.0f);
 	output->xyz_units  = image.get_attribute_as<int>(AttrID_nifti_xyz_units, NIFTI_UNITS_MM);
 	output->time_units = image.get_attribute_as<int>(AttrID_nifti_time_units, NIFTI_UNITS_SEC);
@@ -441,7 +507,8 @@ bool CNifti3DImageIOPlugin::do_save(const std::string& fname, const Data& data)
 
 const std::string CNifti3DImageIOPlugin::do_get_descr() const
 {
-        return "NIFTI-1 3D image IO"; 
+        return "NIFTI-1 3D image IO. The orientation is transformed in the same way like "
+		"it is done with 'dicomtonifti --no-reorder' from the vtk-dicom package."; 
 }
 
 const std::string CNifti3DImageIOPlugin::do_get_preferred_suffix() const
