@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@ using namespace vista_2d_io;
 namespace bmpl=boost::mpl;
 
 typedef bmpl::vector<
-	bool,  
 	unsigned char,
 	signed short,
 	unsigned short,
@@ -79,6 +78,51 @@ BOOST_AUTO_TEST_CASE_TEMPLATE( test_simple_write_read, T, type )
 	iv = image->begin(); 
 
 
+	auto il = ploaded.begin(); 
+	
+	while (iv != ev) {
+		BOOST_CHECK_EQUAL(*il, *iv); 
+		++iv; 
+		++il; 
+	}
+        unlink(filename.str().c_str()); 
+}
+
+BOOST_AUTO_TEST_CASE( test_simple_write_read_bool ) 
+{
+        C2DBounds size(2,3);
+	C2DBitImage *image = new C2DBitImage(size); 
+        P2DImage pimage(image); 
+
+        auto iv = image->begin(); 
+	auto ev = image->end();
+        bool i = false; 
+
+	while (iv != ev) {
+		*iv++ = i;
+		i = !i; 
+	}
+       
+
+	CVista2DImageIOPlugin io; 
+        CVista2DImageIOPlugin::Data images;
+        images.push_back(pimage); 
+
+	stringstream filename; 
+	filename << "testimage-bool.vista2d"; 
+
+	cvdebug() << "test with " << filename.str() << "\n"; 
+
+	BOOST_REQUIRE(io.save(filename.str(), images)); 
+	
+	auto loaded = io.load(filename.str()); 
+	BOOST_REQUIRE(loaded); 
+	
+	BOOST_REQUIRE(loaded->size() == 1u); 
+        const auto& ploaded = dynamic_cast<const C2DBitImage&>(*(*loaded)[0]); 	
+	iv = image->begin(); 
+
+
 	auto il = ploaded.begin(); 
 	
 	while (iv != ev) {
