@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -263,7 +263,7 @@ C2DImageCost *C2DNFGImageCostPlugin::do_create()const
 const string C2DNFGImageCostPlugin::do_get_descr()const
 {
 	return "This function evaluates the image similarity based on normalized gradient fields. "
-		"Various evaluation kernels are availabe.";
+		"Various evaluation kernels are available.";
 }
 
 
