@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -150,7 +150,7 @@ void C2DImageFullCost::do_reinit()
 		throw runtime_error("C2DImageFullCost only works with images of equal size"); 
 	
 	if (m_src->get_pixel_size() != m_ref->get_pixel_size()) {
-		cvwarn() << "C2DImageFullCost: src and reference image are of differnet pixel dimensions:"
+		cvwarn() << "C2DImageFullCost: src and reference image are of different pixel dimensions:"
 			<< m_src->get_pixel_size() << " vs " << m_ref->get_pixel_size() 
 			<< " This code doesn't honour this.\n"; 
 	}
