@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,15 @@
 #include <mia/core/tools.hh>
 #include <libxml++/libxml++.h>
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#if LIBXMLPP_VERSION < 3
+#define add_child_element add_child
+#endif
+
+
 NS_MIA_BEGIN
 
 using namespace xmlpp;
@@ -73,8 +82,8 @@ CSegPoint2D::CSegPoint2D(float x, float y):
 CSegPoint2D::CSegPoint2D(const Node& node)
 {
 	const Element& elm = dynamic_cast<const Element&>(node);
-	Attribute *ax = elm.get_attribute ("x");
-	Attribute *ay = elm.get_attribute ("y");
+	auto *ax = elm.get_attribute ("x");
+	auto *ay = elm.get_attribute ("y");
 	if (!ax || !ay)
 		throw runtime_error("SegSection:Point attribute x or y not found");
 	
@@ -87,9 +96,9 @@ CSegPoint2D::CSegPoint2D(const Node& node)
 					     ay->get_value(), "' is not a floating point value");
 }
 
-void CSegPoint2D::write(Node& node) const
+void CSegPoint2D::write(Element& node) const
 {
-	Element* point = node.add_child("point");
+	Element* point = node.add_child_element("point");
 	point->set_attribute("y", to_string<float>(y));
 	point->set_attribute("x", to_string<float>(x));
 }
