@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,13 @@
 #include <mia/2d/segsection.hh>
 #include <libxml++/libxml++.h>
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#if LIBXMLPP_VERSION < 3
+#define add_child_element add_child
+#endif
 
 NS_MIA_BEGIN
 using namespace std;
@@ -40,19 +47,19 @@ CSegSection::CSegSection(const string& id, const Points& points, bool is_open):
 {
 }
 
-CSegSection::CSegSection(xmlpp::Node& node, int version):
+CSegSection::CSegSection(const xmlpp::Node& node, int version):
 	m_is_open(false)
 {
 	TRACE("CSegSection::CSegSection");
 
-	xmlpp::Element& elm = dynamic_cast<xmlpp::Element&>(node);
-	xmlpp::Attribute *id = elm.get_attribute ("color");
+	const xmlpp::Element& elm = dynamic_cast<const xmlpp::Element&>(node);
+	auto *id = elm.get_attribute ("color");
 
 	if (!id)
 		throw invalid_argument("CSegSection::CSegSection: node without id");
 	m_id = id->get_value();
 
-	xmlpp::Node::NodeList points = node.get_children("point");
+	auto points = node.get_children("point");
 
 	for (auto i = points.begin(); i != points.end(); ++i)
 		m_points.push_back(CSegPoint2D(**i));
@@ -97,9 +104,9 @@ void CSegSection::inv_transform(const C2DTransformation& t)
 }
 
 
-void CSegSection::write(xmlpp::Node& node, int version) const
+void CSegSection::write(xmlpp::Element& node, int version) const
 {
-	xmlpp::Element* nodeChild = node.add_child("section");
+	xmlpp::Element* nodeChild = node.add_child_element("section");
 	nodeChild->set_attribute("color", m_id);
 
 	if (version > 1) {
