@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,7 +128,7 @@ TPluginHandler<C2DSplineTransformPenaltyPlugin>::m_help =
 	"This class provides the penalty put on spline based transformations  "
 	"when considering image registration. This penalty term ensures "
 	"the smoothness of a transformation or the evaluation of a similarity measure "
-	"between a transformed study data set and a refernce data set.";
+	"between a transformed study data set and a reference data set.";
 
 
 EXPLICIT_INSTANCE_DERIVED_FACTORY_HANDLER(C2DSplineTransformPenalty, C2DSplineTransformPenaltyPlugin); 
