@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,9 +22,7 @@
 
 #include <mia/core/threadedmsg.hh>
 #include <mia/core/nccsum.hh>
-#include <tbb/parallel_reduce.h>
-#include <tbb/blocked_range.h>
-
+#include <mia/core/parallel.hh>
 
 NS_BEGIN(NS)
 
@@ -69,7 +67,7 @@ public:
 	
 	template <typename T, typename R> 
 	float operator () ( const T& mov, const R& ref) const {
-		auto evaluate_local_cost = [this, &mov, &ref](const tbb::blocked_range<size_t>& range, const pair<float, int>& result) -> pair<float, int> {
+		auto evaluate_local_cost = [this, &mov, &ref](const C1DParallelRange& range, const pair<float, int>& result) -> pair<float, int> {
 			CThreadMsgStream msks; 
 			float lresult = 0.0; 
 			int count = 0; 
@@ -104,10 +102,10 @@ public:
 		};
 		
 		pair<float,int> init{0, 0}; 
-		auto r = parallel_reduce(tbb::blocked_range<size_t>(0, mov.get_size().z, 1), init, evaluate_local_cost, 
-					 [](const pair<float,int>& x, const pair<float,int>& y){
-						 return make_pair(x.first + y.first, x.second + y.second);
-					 });	
+		auto r = preduce(C1DParallelRange(0, mov.get_size().z, 1), init, evaluate_local_cost, 
+				 [](const pair<float,int>& x, const pair<float,int>& y){
+					 return make_pair(x.first + y.first, x.second + y.second);
+				 });	
 		return r.second > 0 ? r.first / r.second : 0.0; 
 	}
 }; 
@@ -132,7 +130,7 @@ public:
 	template <typename T, typename R> 
 	float operator () ( const T& mov, const R& ref) const {
 		auto ag = get_gradient(mov); 
-		auto evaluate_local_cost_force = [this, &mov, &ref, &ag](const tbb::blocked_range<size_t>& range, 
+		auto evaluate_local_cost_force = [this, &mov, &ref, &ag](const C1DParallelRange& range, 
 									 const pair<float, int>& result) -> pair<float, int> {
 			
 			CThreadMsgStream msks; 		
@@ -175,10 +173,10 @@ public:
 			return make_pair(result.first + lresult, result.second + count); 
 		};
 		pair<float,int> init{0, 0}; 		
-		auto r = parallel_reduce(tbb::blocked_range<size_t>(0, mov.get_size().z, 1), init, evaluate_local_cost_force, 
-					 [](const pair<float,int>& x, const pair<float,int>& y){
-						 return make_pair(x.first + y.first, x.second + y.second);
-					 });
+		auto r = preduce(C1DParallelRange(0, mov.get_size().z, 1), init, evaluate_local_cost_force, 
+				 [](const pair<float,int>& x, const pair<float,int>& y){
+					 return make_pair(x.first + y.first, x.second + y.second);
+				 });
 		
 		return r.second > 0 ? r.first / r.second : 0.0; 
 	}
