@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,14 +95,15 @@ INSTANCIATE(short);
 INSTANCIATE(unsigned short);
 INSTANCIATE(unsigned char );
 INSTANCIATE(signed char);
-INSTANCIATE(bool);
+template class  T3DDatafield<bool>;
 
 DEFINE_TYPE_DESCR2(C3DBounds, "3dbounds"); 
 DEFINE_TYPE_DESCR2(C3DFVector, "3dfvector"); 
 
-template class EXPORT_3D  CTParameter<C3DBounds>;
-template class EXPORT_3D  CTParameter<C3DFVector>;
-template class EXPORT_3D  TTranslator<C3DFVector>; 
+template class CTParameter<C3DBounds>;
+template class CTParameter<C3DFVector>;
+template class TTranslator<C3DFVector>; 
+template class TAttribute<C3DFVector>; 
 
 NS_MIA_END
 
