@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -359,7 +359,7 @@ void C3DTaggedSSDCost::do_reinit()
 		
 	
 		if (m_src[i]->get_voxel_size() != m_ref[i]->get_voxel_size()) {
-			cverr() << "C3DImageFullCost: src and reference image are of differnet pixel dimensions."
+			cverr() << "C3DImageFullCost: src and reference image are of different pixel dimensions."
 				<< "This code doesn't honour this and a proper scaling should be applied first."; 
 		}
 	}
