@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@
 #pragma GCC diagnostic push
 #ifndef __clang__ 
 #pragma GCC diagnostic ignored "-Wunused-local-typedefs"
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #else
 #pragma clang diagnostic ignored "-Wdeprecated-register"
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #endif 
 #endif 
 
@@ -43,7 +45,7 @@ NS_MIA_BEGIN
 template <typename T> 
 T3DMatrix<T>::T3DMatrix():
         m_ev_type(0),
-	m_evectors(3),
+	m_complex_evectors(3),
 	m_ev_order(3)
 {
 }
@@ -69,7 +71,7 @@ template <typename T>
 T3DMatrix<T>::T3DMatrix(const T3DVector< T3DVector<T> >& other):
 	T3DVector<T3DVector<T> >(other.x, other.y, other.z),
 	m_ev_type(0),
-	m_evectors(3),
+	m_complex_evectors(3),
 	m_ev_order(3)
 {
 }
@@ -78,7 +80,7 @@ template <typename T>
 T3DMatrix<T>::T3DMatrix(const T3DVector< T >& x, const T3DVector< T >& y, const T3DVector< T >& z ):
 	T3DVector<T3DVector<T> >(x, y, z),
 	m_ev_type(0),
-	m_evectors(3),
+	m_complex_evectors(3),
 	m_ev_order(3)
 {
 }
@@ -139,7 +141,6 @@ void T3DMatrix<T>::evaluate_ev() const
 			evnorms[i] = std::norm(eval(i)); 
 		
 		
-		
 		if (evnorms[0] < evnorms[1]) {
 			if (evnorms[0] < evnorms[2]) {
 				m_ev_order[2] = 0; 
@@ -191,15 +192,21 @@ void T3DMatrix<T>::evaluate_ev() const
 		m_evalues.y = eval[m_ev_order[1]].real(); 
 		m_evalues.z = eval[m_ev_order[2]].real();
 		
-		if (m_evalues.x == m_evalues.y || m_evalues.y == m_evalues.z) 
-			m_ev_type = 2;
-		else 
-			m_ev_type = 3; 
+		if (m_evalues.x == m_evalues.y || m_evalues.y == m_evalues.z) {
+			if (m_evalues.x == m_evalues.y && m_evalues.y == m_evalues.z)
+				m_ev_type = 4;
+			else
+				m_ev_type = 2;
+		}else {
+			m_ev_type = 3;
+		}
 	}
 	assert(m_ev_type);
 	for (int i = 0; i < 3; ++i) {
 		const auto evec = esolver.eigenvectors().col(m_ev_order[i]);
-		m_evectors[i] = C3DFVector(evec(0).real(), evec(1).real(), evec(2).real());
+		cvdebug() << "i: eval= " << eval[m_ev_order[i]]
+			  << "evec= " << evec(0) << ", " << evec(1) << "," << evec(2) << "\n"; 
+		m_complex_evectors[i] = T3DCVector<T>(evec(0), evec(1), evec(2));
 	}
 }
 
@@ -237,7 +244,7 @@ T T3DMatrix<T>::get_det()  const
 
 
 template <typename T> 
-int T3DMatrix<T>::get_eigenvalues(C3DFVector& result)const
+int T3DMatrix<T>::get_eigenvalues(T3DVector<T>& result)const
 {
 	if (m_ev_type == 0) 
 		evaluate_ev(); 
@@ -247,14 +254,25 @@ int T3DMatrix<T>::get_eigenvalues(C3DFVector& result)const
 }
 
 template <typename T> 
-C3DFVector T3DMatrix<T>::get_eigenvector(int i)const
+T3DCVector<T> T3DMatrix<T>::get_complex_eigenvector(int i)const
 {
 	if (m_ev_type == 0) 
 		evaluate_ev(); 
 	
-	return m_evectors[i];
+	return m_complex_evectors[i];
 }
 
+template <typename T> 
+T3DVector<T> T3DMatrix<T>::get_real_eigenvector(int i)const
+{
+	if (m_ev_type == 0) 
+		evaluate_ev(); 
+
+	auto evec = m_complex_evectors[i]; 
+	return T3DVector<T>(evec.x.real(), evec.y.real(), evec.z.real()); 
+}
+
+
 template class T3DMatrix<float>; 
 template class T3DMatrix<double>; 
 
